from typing import Any, Dict, List, Type, TypeVar

import attr

T = TypeVar(
    "T", bound="ExploitsApiV1ReportExplanationsRetrieveResponse200ExplanationsItem"
)


@attr.s(auto_attribs=True)
class ExploitsApiV1ReportExplanationsRetrieveResponse200ExplanationsItem:
    """ """

    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        exploits_api_v1_report_explanations_retrieve_response_200_explanations_item = (
            cls()
        )

        exploits_api_v1_report_explanations_retrieve_response_200_explanations_item.additional_properties = (
            d
        )
        return (
            exploits_api_v1_report_explanations_retrieve_response_200_explanations_item
        )

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
